@@ -18,6 +18,7 @@
 from __future__ import annotations
 
 import tempfile
+import warnings
 from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
@@ -84,6 +85,10 @@ class AzureBlobStorageToGCSOperator(BaseOperator):
         self.object_name = object_name
         self.filename = filename
         self.gzip = gzip
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
